aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAhmed Ashour <asashour@yahoo.com>2017-10-04 10:29:34 +0200
committerHenri Sara <henri.sara@gmail.com>2017-10-04 11:29:34 +0300
commit83f5e593f66d36d99b22298e8023afd3c31a6122 (patch)
treef17f2a455cd928e3867f58274df68b4014da781d
parentf265739578783ca08b7829ba030a38574b3ed4a7 (diff)
downloadvaadin-framework-83f5e593f66d36d99b22298e8023afd3c31a6122.tar.gz
vaadin-framework-83f5e593f66d36d99b22298e8023afd3c31a6122.zip
Fix typos (#10124)
-rw-r--r--client/src/main/java/com/vaadin/client/communication/XhrConnectionError.java4
-rw-r--r--client/src/main/java/com/vaadin/client/ui/VAbstractSplitPanel.java2
-rw-r--r--client/src/main/java/com/vaadin/client/ui/dd/VDropHandler.java2
-rw-r--r--client/src/main/java/com/vaadin/client/widgets/ChildFocusAwareFlowPanel.java20
-rw-r--r--compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java25
-rw-r--r--compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java4
-rw-r--r--compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java4
-rw-r--r--compatibility-server/src/main/java/com/vaadin/v7/data/util/HierarchicalContainer.java2
-rw-r--r--compatibility-server/src/main/java/com/vaadin/v7/ui/Upload.java4
-rw-r--r--documentation/articles/ComponentAddonProjectSetupHOWTO.asciidoc6
-rw-r--r--documentation/articles/ConfigureInputFieldsToGuideDataEntry.asciidoc2
-rw-r--r--documentation/articles/CreatingASimpleComponentContainer.asciidoc2
-rw-r--r--documentation/articles/CreatingAThemeUsingSass.asciidoc2
-rw-r--r--documentation/articles/EnableAndDisableButtonsToIndicateState.asciidoc2
-rw-r--r--documentation/articles/FindingTheCurrentUIAndPageAndVaadinSession.asciidoc2
-rw-r--r--documentation/articles/IIInjectionAndScopes.asciidoc2
-rw-r--r--documentation/articles/IntegrationExperiences.asciidoc4
-rw-r--r--documentation/articles/LoadTestingWithGatling.asciidoc8
-rw-r--r--documentation/articles/MVCBasicsInITMillToolkit.asciidoc2
-rw-r--r--documentation/articles/OptimizingSluggishUI.asciidoc4
-rw-r--r--documentation/articles/ReadOnlyVsDisabledFields.asciidoc2
-rw-r--r--documentation/articles/SettingAndReadingCookies.asciidoc2
-rw-r--r--documentation/articles/SettingAndReadingSessionAttributes.asciidoc2
-rw-r--r--documentation/articles/UsingFontIcons.asciidoc4
-rw-r--r--documentation/articles/UsingVaadinInIBMDomino.asciidoc2
-rw-r--r--documentation/articles/Vaadin7SpringSecurityBaseAuthentification.asciidoc2
-rw-r--r--documentation/articles/VaadinCDI.asciidoc2
-rw-r--r--documentation/articles/VaadinOnGrailsDatabaseAccess.asciidoc2
-rw-r--r--server/src/main/java/com/vaadin/data/Binder.java11
-rw-r--r--server/src/main/java/com/vaadin/event/MouseEvents.java8
-rw-r--r--server/src/main/java/com/vaadin/server/SessionExpiredHandler.java6
-rw-r--r--server/src/main/java/com/vaadin/server/VaadinService.java4
-rw-r--r--server/src/main/java/com/vaadin/ui/Button.java8
-rw-r--r--server/src/main/java/com/vaadin/ui/Upload.java4
-rw-r--r--server/src/main/java/com/vaadin/util/TimeZoneUtil.java4
-rw-r--r--server/src/test/java/com/vaadin/tests/server/ClassesSerializableTest.java2
-rw-r--r--shared/src/main/java/com/vaadin/shared/ui/grid/GridDropTargetRpc.java19
-rw-r--r--uitest/eclipse-run-selected-test.properties2
-rw-r--r--uitest/src/main/java/com/vaadin/tests/CustomLayoutDemo.java2
-rw-r--r--uitest/src/main/java/com/vaadin/tests/TestBench.java2
-rw-r--r--uitest/src/main/java/com/vaadin/tests/TestCaptionWrapper.java5
-rw-r--r--uitest/src/main/java/com/vaadin/tests/TreeFilesystemContainer.java2
-rw-r--r--uitest/src/main/java/com/vaadin/tests/components/button/ButtonClick.java2
-rw-r--r--uitest/src/main/java/com/vaadin/tests/components/draganddropwrapper/SingleUseDragAndDropUpload.java2
-rw-r--r--uitest/src/main/java/com/vaadin/tests/components/grid/basics/GridBasics.java27
-rw-r--r--uitest/src/main/java/com/vaadin/tests/components/orderedlayout/VaadinTunesLayout.java27
-rw-r--r--uitest/src/main/java/com/vaadin/tests/components/tree/TreeBasicFeatures.java5
-rw-r--r--uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectAllTest.java4
-rw-r--r--uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectionTest.java2
-rw-r--r--uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorBufferedTest.java2
-rw-r--r--uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorUnbufferedTest.java10
-rw-r--r--uitest/src/test/java/com/vaadin/tests/components/table/MemoryLeakTableTest.java4
-rw-r--r--uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorBufferedTest.java4
-rw-r--r--uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorTest.java16
-rw-r--r--uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorUnbufferedTest.java10
-rw-r--r--uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridStructureTest.java2
56 files changed, 163 insertions, 154 deletions
diff --git a/client/src/main/java/com/vaadin/client/communication/XhrConnectionError.java b/client/src/main/java/com/vaadin/client/communication/XhrConnectionError.java
index 2823865d5a..a4e398c2dd 100644
--- a/client/src/main/java/com/vaadin/client/communication/XhrConnectionError.java
+++ b/client/src/main/java/com/vaadin/client/communication/XhrConnectionError.java
@@ -21,8 +21,8 @@ import com.google.gwt.http.client.Response;
import elemental.json.JsonObject;
/**
- * XhrConnectionError provides detail about an error which occured during an XHR
- * request to the server.
+ * XhrConnectionError provides detail about an error which occurred during
+ * an XHR request to the server.
*
* @since 7.6
* @author Vaadin Ltd
diff --git a/client/src/main/java/com/vaadin/client/ui/VAbstractSplitPanel.java b/client/src/main/java/com/vaadin/client/ui/VAbstractSplitPanel.java
index bdd50934b9..238e8e9284 100644
--- a/client/src/main/java/com/vaadin/client/ui/VAbstractSplitPanel.java
+++ b/client/src/main/java/com/vaadin/client/ui/VAbstractSplitPanel.java
@@ -579,7 +579,7 @@ public abstract class VAbstractSplitPanel extends ComplexPanel {
if (WidgetUtil.isTouchEvent(event) || !resized) {
super.onBrowserEvent(event);
} else if (DOM.eventGetType(event) == Event.ONMOUSEUP) {
- // Reset the resized flag after a mouseup has occured so the next
+ // Reset the resized flag after a mouseup has occurred so the next
// mousedown/mouseup can be interpreted as a click.
resized = false;
}
diff --git a/client/src/main/java/com/vaadin/client/ui/dd/VDropHandler.java b/client/src/main/java/com/vaadin/client/ui/dd/VDropHandler.java
index 690ea6b378..4cd697c4a5 100644
--- a/client/src/main/java/com/vaadin/client/ui/dd/VDropHandler.java
+++ b/client/src/main/java/com/vaadin/client/ui/dd/VDropHandler.java
@@ -83,7 +83,7 @@ public interface VDropHandler {
/**
* Returns the application connection to which this {@link VDropHandler}
- * belongs to. DragAndDropManager uses this fucction to send Transferable to
+ * belongs to. DragAndDropManager uses this function to send Transferable to
* server side.
*/
public ApplicationConnection getApplicationConnection();
diff --git a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java
index 751f7cb3fe..af7b78b271 100644
--- a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java
+++ b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VScrollTable.java
@@ -1375,7 +1375,7 @@ public class VScrollTable extends FlowPanel
/** For internal use only. May be removed or replaced in the future. */
public void resizeSortedColumnForSortIndicator() {
// Force recalculation of the captionContainer element inside the header
- // cell to accomodate for the size of the sort arrow.
+ // cell to accommodate for the size of the sort arrow.
HeaderCell sortedHeader = tHead.getHeaderCell(sortColumn);
if (sortedHeader != null) {
// Mark header as sorted now. Any earlier marking would lead to
@@ -3679,7 +3679,7 @@ public class VScrollTable extends FlowPanel
}
if (col.hasAttribute("width") && !c.isResizing) {
- // Make sure to accomodate for the sort indicator if
+ // Make sure to accommodate for the sort indicator if
// necessary.
int width = col.getIntAttribute("width");
int widthWithoutAddedIndent = width;
diff --git a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java
index d60aa7f6de..bc08421d4c 100644
--- a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java
+++ b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/calendar/schedule/CalendarEvent.java
@@ -186,7 +186,7 @@ public class CalendarEvent {
/**
* Get the description of the event. The description is the text displayed
- * when hoovering over the event with the mouse
+ * when hovering over the event with the mouse
*
* @return
*/
@@ -196,7 +196,7 @@ public class CalendarEvent {
/**
* Set the description of the event. The description is the text displayed
- * when hoovering over the event with the mouse
+ * when hovering over the event with the mouse
*
* @param description
*/
diff --git a/compatibility-server/src/main/java/com/vaadin/v7/data/util/HierarchicalContainer.java b/compatibility-server/src/main/java/com/vaadin/v7/data/util/HierarchicalContainer.java
index ad995fa20a..c5ecee9e77 100644
--- a/compatibility-server/src/main/java/com/vaadin/v7/data/util/HierarchicalContainer.java
+++ b/compatibility-server/src/main/java/com/vaadin/v7/data/util/HierarchicalContainer.java
@@ -622,7 +622,7 @@ public class HierarchicalContainer extends IndexedContainer
}
}
}
- // remove the root of subtree if children where succesfully removed
+ // remove the root of subtree if children where successfully removed
if (success) {
success = container.removeItem(itemId);
}
diff --git a/compatibility-server/src/main/java/com/vaadin/v7/ui/Upload.java b/compatibility-server/src/main/java/com/vaadin/v7/ui/Upload.java
index df95453a64..b66531df24 100644
--- a/compatibility-server/src/main/java/com/vaadin/v7/ui/Upload.java
+++ b/compatibility-server/src/main/java/com/vaadin/v7/ui/Upload.java
@@ -614,10 +614,10 @@ public class Upload extends AbstractLegacyComponent
public interface SucceededListener extends Serializable {
/**
- * Upload successfull..
+ * Upload successful.
*
* @param event
- * the Upload successfull event.
+ * the Upload successful event.
*/
public void uploadSucceeded(SucceededEvent event);
}
diff --git a/documentation/articles/ComponentAddonProjectSetupHOWTO.asciidoc b/documentation/articles/ComponentAddonProjectSetupHOWTO.asciidoc
index a0730f45bd..e8d063e27c 100644
--- a/documentation/articles/ComponentAddonProjectSetupHOWTO.asciidoc
+++ b/documentation/articles/ComponentAddonProjectSetupHOWTO.asciidoc
@@ -96,7 +96,7 @@ src directory from Navigator view and select Team -> Add to Index. Then
add the rest of the files (.settings, .project, .classpath and target)
to .gitignore with Team -> Ignore. Finally, just do Team -> Commit.
-At this point - or later whenevery you are ready for it - you can
+At this point - or later whenever you are ready for it - you can
publish the project to GitHub. Just go to github.com and create a new
repository. Use MyList as the name for the repository. Then follow the
instructions on the screen. In my case, I executed the following command
@@ -123,12 +123,12 @@ for Maven run configuration for "jetty:run". Now when you make any
changes to server-side code - for example to `WidgetTestApplication.java`
- hit save and reload the browser pointing to
http://localhost:8080/mylist/?restartApplication, the changes are
-appliead immediately. Even better - you can start the project with Debug
+applied immediately. Even better - you can start the project with Debug
As and add break points to the application.
Client-side changes are more tricky as they are compiled from Java to
JavaScript by GWT. To make those changes immediately you, must be
-running a GWT Devepment Mode. This is done by running Maven goal gwt:run
+running a GWT Development Mode. This is done by running Maven goal gwt:run
instead of just pointing your web browser to the running application.
Note that must be running both jetty:run and gwt:run concurrently.
gwt:run starts application called "GWT Development Mode". From there you
diff --git a/documentation/articles/ConfigureInputFieldsToGuideDataEntry.asciidoc b/documentation/articles/ConfigureInputFieldsToGuideDataEntry.asciidoc
index 8c32561ab1..cb08a16951 100644
--- a/documentation/articles/ConfigureInputFieldsToGuideDataEntry.asciidoc
+++ b/documentation/articles/ConfigureInputFieldsToGuideDataEntry.asciidoc
@@ -22,7 +22,7 @@ image:img/form1.png[Basic form]
The shape, size and layout of these fields don’t really correspond to
the kinds of values expected to be entered in them, or to the relations
between different fields. For instance, while the homepage url is
-probably between 25 and 55 characters long, european postal codes are
+probably between 25 and 55 characters long, European postal codes are
only about 6 digits long, and age maxes out at three digits. By setting
the widths of these fields to be approximately proportional to the
lengths of expected values, the fields become easier to identify, and
diff --git a/documentation/articles/CreatingASimpleComponentContainer.asciidoc b/documentation/articles/CreatingASimpleComponentContainer.asciidoc
index 5e25aa2144..7a94c85ec8 100644
--- a/documentation/articles/CreatingASimpleComponentContainer.asciidoc
+++ b/documentation/articles/CreatingASimpleComponentContainer.asciidoc
@@ -13,7 +13,7 @@ and `ComponentContainer`{empty}s. ComponentContainers are Components in
themselves which can also contain other components. If you are about to
implement a component that contains other components, then you'll get a
headstart by extending Vaadin's `ComponentContainer`. The biggest feature
-is in tranferring the list of server side components from your component
+is in transferring the list of server side components from your component
to the client. Here's how you do it.
[[server-side]]
diff --git a/documentation/articles/CreatingAThemeUsingSass.asciidoc b/documentation/articles/CreatingAThemeUsingSass.asciidoc
index 4e3ca2c77c..0b1babae76 100644
--- a/documentation/articles/CreatingAThemeUsingSass.asciidoc
+++ b/documentation/articles/CreatingAThemeUsingSass.asciidoc
@@ -135,7 +135,7 @@ that the name matches your themename, or your styles will not be
applied._
Some of the nice features you get with Sass include variables, selector
-nesting, mixins (optionally with paramaters), selector inheritance. For
+nesting, mixins (optionally with parameters), selector inheritance. For
more information of what you can do with Sass, you should refer to the
official documentation at http://sass-lang.com
diff --git a/documentation/articles/EnableAndDisableButtonsToIndicateState.asciidoc b/documentation/articles/EnableAndDisableButtonsToIndicateState.asciidoc
index c963d8533a..4acc90440b 100644
--- a/documentation/articles/EnableAndDisableButtonsToIndicateState.asciidoc
+++ b/documentation/articles/EnableAndDisableButtonsToIndicateState.asciidoc
@@ -59,7 +59,7 @@ spared the trouble of attempting in vain to perform the action, and the
nuisance of an error message.
image:img/potus2.png[Save and Revert actions disabled when they cannot be
-succesfully
+successfully
performed.]
[[disablingenabling-actions-to-indicate-state]]
diff --git a/documentation/articles/FindingTheCurrentUIAndPageAndVaadinSession.asciidoc b/documentation/articles/FindingTheCurrentUIAndPageAndVaadinSession.asciidoc
index 6be26d18d9..ad2c3b7a7b 100644
--- a/documentation/articles/FindingTheCurrentUIAndPageAndVaadinSession.asciidoc
+++ b/documentation/articles/FindingTheCurrentUIAndPageAndVaadinSession.asciidoc
@@ -47,7 +47,7 @@ public void buttonClick(ClickEvent event) {
}
....
-And finally similiarly for `Page`. For instance adding a browser window
+And finally similarly for `Page`. For instance adding a browser window
resize listener can be added like this:
[source,java]
diff --git a/documentation/articles/IIInjectionAndScopes.asciidoc b/documentation/articles/IIInjectionAndScopes.asciidoc
index cbf843ebde..f8aa692bd8 100644
--- a/documentation/articles/IIInjectionAndScopes.asciidoc
+++ b/documentation/articles/IIInjectionAndScopes.asciidoc
@@ -147,7 +147,7 @@ public class UserInfo implements Serializable {
....
We'll inject that to the UI and assign the user some name during
-initalization (for now)
+initialization (for now)
[source,java]
....
diff --git a/documentation/articles/IntegrationExperiences.asciidoc b/documentation/articles/IntegrationExperiences.asciidoc
index 8680a690f0..2ae8ab3f43 100644
--- a/documentation/articles/IntegrationExperiences.asciidoc
+++ b/documentation/articles/IntegrationExperiences.asciidoc
@@ -96,7 +96,7 @@ with hierarchical table aka treetable. Another simple but important
widget was multilingual text field. It acts just like normal textfield
but when opened, you get the java field opened with multiple locale
instances, it has nice UI too including user friendly flags. Great for
-handling i18n based data in your UI. We got multiple customercases that
+handling i18n based data in your UI. We got multiple customer cases that
enjoy these new widgets. -*Jani Laakso*
===============================
@@ -259,7 +259,7 @@ business logic inside UI logic, there's no need to. This way the UI can
be replaced in the future and also when updating old systems to use
Vaadin (e.g. SWING applications that are written this way) it has been a
breeze when the only thing that needs to be rewritten is the UI. Another
-very imporant factor is security, trust your data layer, do not trust
+very important factor is security, trust your data layer, do not trust
your clients, using enterprise beans with JNDI helps you. Scalability
and high-availability are also easier to cope with. Scale up with
multiple cheap Tomcat machines acting as Vaadin clients, few powerful
diff --git a/documentation/articles/LoadTestingWithGatling.asciidoc b/documentation/articles/LoadTestingWithGatling.asciidoc
index c13b84098c..a76a579066 100644
--- a/documentation/articles/LoadTestingWithGatling.asciidoc
+++ b/documentation/articles/LoadTestingWithGatling.asciidoc
@@ -30,7 +30,7 @@ properly.
The communication that Vaadin's "thin client" in browser does with the
server side has couple of checks that it does to improve robustness and
security. One can simulate these with Gatling as well, by e.g.
-https://github.com/mstahv/v-quiz/blob/master/src/test/scala/loadtest/WebSocketVaadinSimulation.scala#L84[reading the XSRF preventation key into a variable] and passing the value
+https://github.com/mstahv/v-quiz/blob/master/src/test/scala/loadtest/WebSocketVaadinSimulation.scala#L84[reading the XSRF prevention key into a variable] and passing the value
https://github.com/mstahv/v-quiz/blob/master/src/test/scala/loadtest/WebSocketVaadinSimulation.scala#L95[in
each response]. However, these setting can be disabled during load
testing to make it easier to write and maintain your application. The
@@ -43,7 +43,7 @@ separate maven profile and inject different parameters with it.
Disabling XSRF presentation key
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-The XSRF preventation can be disabled with following servlet parameter
+The XSRF prevention can be disabled with following servlet parameter
(or similar servlet 3 style parameter). NOTE, do not leave this for
public apps in production.
@@ -117,7 +117,7 @@ communication channel, WebSockets, you can do that with Gatling as well.
Using the recorder in this case doesn't work, but handcrafting the test
case isn't that hard once you get started. The example app has a branch
with WebSocket test case. With WebSocket communication it might also be
-handy to disable xsrf preventation and the so called "syncid".
+handy to disable xsrf prevention and the so called "syncid".
First two request are just normal http requests. The first gets the
"host page" and also the initial state request is done with normal XHR.
@@ -161,7 +161,7 @@ message that the server sends when you connect to it. 
Check out this script for
https://github.com/mstahv/v-quiz/blob/master/src/test/scala/loadtest/WebSocketVaadinSimulation.scala[an
-example using WebSocket] communication. It also saves XSRF preventation
+example using WebSocket] communication. It also saves XSRF prevention
key to variable, so it don't need it to be disabled from the server.
[[configuring-gatling-to-the-web-app-build]]
diff --git a/documentation/articles/MVCBasicsInITMillToolkit.asciidoc b/documentation/articles/MVCBasicsInITMillToolkit.asciidoc
index 78b2f4848b..3f4f24d318 100644
--- a/documentation/articles/MVCBasicsInITMillToolkit.asciidoc
+++ b/documentation/articles/MVCBasicsInITMillToolkit.asciidoc
@@ -13,7 +13,7 @@ The Goal
image:img/moduleDesign.jpg[1]
-We want to create a simple UI following the MVC pattern using the IT Mill Toolkit. The project components need to have low coupling and follow an enterprise design. In our example we also want to retrieve information from a database and display it in the view. The different parts of the UI need also to be able to communicate with eachother.
+We want to create a simple UI following the MVC pattern using the IT Mill Toolkit. The project components need to have low coupling and follow an enterprise design. In our example we also want to retrieve information from a database and display it in the view. The different parts of the UI need also to be able to communicate with each other.
We have divided the project in two layers; A UI layer, which purpose is to display information to the user, and a Data layer which has no knowledge of the Toolkit and which is only responsible for retrieving and storing data. The reason for dividing the project up in these layers is so that, if we choose, we can easily use multiple servers.
diff --git a/documentation/articles/OptimizingSluggishUI.asciidoc b/documentation/articles/OptimizingSluggishUI.asciidoc
index a3a7ffae66..4f4d98e60c 100644
--- a/documentation/articles/OptimizingSluggishUI.asciidoc
+++ b/documentation/articles/OptimizingSluggishUI.asciidoc
@@ -94,8 +94,8 @@ http://uilder.virtuallypreinstalled.com/run/deepcomponenttrees/?restartApplicati
layouts when possible
* Do you need to extend CustomComponent in your server side composition
or could you just extend some layout? This will result having one
-component less in the component tree. You might sometimes be argueing
-against this because of architectual reasons (CustomComponent has a
+component less in the component tree. You might sometimes be arguing
+against this because of architectural reasons (CustomComponent has a
fewer methods than VerticalLayout), but on the other hand Java has
interfaces to deal the issue in a cleaner manner.
* Maybe you have an  extra layout inside your Panel or Window (see
diff --git a/documentation/articles/ReadOnlyVsDisabledFields.asciidoc b/documentation/articles/ReadOnlyVsDisabledFields.asciidoc
index 80f054f531..3d9ae230fb 100644
--- a/documentation/articles/ReadOnlyVsDisabledFields.asciidoc
+++ b/documentation/articles/ReadOnlyVsDisabledFields.asciidoc
@@ -96,7 +96,7 @@ one might expect. Doing the same with _disabled does_, though.)
One caveat regarding read-only fields is that if the text is longer than
the field, it will be clipped, as opposed to a Label, which instead will
wrap the text to a new line. Thus, in certain situations, switching to
-Labels may be preferrable.
+Labels may be preferable.
It’s probably best to mention here that *setReadOnly(true)* also has a
certain side-effect in Vaadin that *setEnabled(false)* does not: You
diff --git a/documentation/articles/SettingAndReadingCookies.asciidoc b/documentation/articles/SettingAndReadingCookies.asciidoc
index 3a310e7d96..1027c60bbb 100644
--- a/documentation/articles/SettingAndReadingCookies.asciidoc
+++ b/documentation/articles/SettingAndReadingCookies.asciidoc
@@ -13,7 +13,7 @@ http://en.wikipedia.org/wiki/HTTP_cookie[cookies] from both the server
and the client side in Vaadin, with one caveat: Cookies are not possible
if you enable Push using WebSocket (see tickets
http://dev.vaadin.com/ticket/11808[11808] and
-http://dev.vaadin.com/ticket/12518[12518]). Begining in Vaadin 7.6,
+http://dev.vaadin.com/ticket/12518[12518]). Beginning in Vaadin 7.6,
cookies can be used with the WEBSOCKET_XHR transport type.
The
diff --git a/documentation/articles/SettingAndReadingSessionAttributes.asciidoc b/documentation/articles/SettingAndReadingSessionAttributes.asciidoc
index 4d96c47e5c..72db6bef11 100644
--- a/documentation/articles/SettingAndReadingSessionAttributes.asciidoc
+++ b/documentation/articles/SettingAndReadingSessionAttributes.asciidoc
@@ -14,7 +14,7 @@ data, e.g. how long it should be kept around and what parts of the code
should have access to it.
1. Store the data as a field in your UI subclass. The data is easily
-accesible from components belonging to that UI instance and the data
+accessible from components belonging to that UI instance and the data
will be gone when the UI is closed.
2. Store data in the `VaadinServiceSession`. The data is easily
accessible from any UI belonging to the same VaadinServlet or
diff --git a/documentation/articles/UsingFontIcons.asciidoc b/documentation/articles/UsingFontIcons.asciidoc
index 3741163156..7713f48c74 100644
--- a/documentation/articles/UsingFontIcons.asciidoc
+++ b/documentation/articles/UsingFontIcons.asciidoc
@@ -54,7 +54,7 @@ Making a custom set of icons
~~~~~~~~~~~~~~~~~~~~~~~~~~~~
There are many tools for making icons, and icon fonts. One of our
-favourite tools is http://icomoon.io/app[IcoMoon], which is an excellent
+favorite tools is http://icomoon.io/app[IcoMoon], which is an excellent
online application where you can pick icons from a vast library of
ready-made icon fonts, to compose your own set of icons. When you’re
done, you can download a zip that contains your font files - just copy
@@ -67,7 +67,7 @@ automatically)
4. Mark the icons you want in your font
5. _Download_ the font
-In IcoMoon you can also produce a customised version of FontAwesome, if
+In IcoMoon you can also produce a customized version of FontAwesome, if
you for instance want to remove unused icons, or swap individual icons.
You can also re-upload your custom icon font, if you want to make
changes or additions to it later. 
diff --git a/documentation/articles/UsingVaadinInIBMDomino.asciidoc b/documentation/articles/UsingVaadinInIBMDomino.asciidoc
index 25a28bd7ad..35ffcbc8d4 100644
--- a/documentation/articles/UsingVaadinInIBMDomino.asciidoc
+++ b/documentation/articles/UsingVaadinInIBMDomino.asciidoc
@@ -286,7 +286,7 @@ image:img/domino15.png[15]
com.paulwithers.helloVaadinFeature.
image:img/domino16.png[16]
-27. Click Next and initialise from the com.paulwithers.helloVaadin
+27. Click Next and initialize from the com.paulwithers.helloVaadin
plugin.
28. Select *File* > *New* > *Update Site Project*. Call it
diff --git a/documentation/articles/Vaadin7SpringSecurityBaseAuthentification.asciidoc b/documentation/articles/Vaadin7SpringSecurityBaseAuthentification.asciidoc
index 4881d35c2d..4350274539 100644
--- a/documentation/articles/Vaadin7SpringSecurityBaseAuthentification.asciidoc
+++ b/documentation/articles/Vaadin7SpringSecurityBaseAuthentification.asciidoc
@@ -11,7 +11,7 @@ Vaadin 7 + Spring Security (base authentication)
Vaadin 7 is easy to integrate with Spring Security. You should configure only
2 files. First - web.xml and second one spring-security.xml (user
credentials and security settings). This is a small example on how to use
-base form for authentification.
+base form for authentication.
[[web.xml-configuration]]
web.xml Configuration
diff --git a/documentation/articles/VaadinCDI.asciidoc b/documentation/articles/VaadinCDI.asciidoc
index 99b1efd16d..16d4cbc323 100644
--- a/documentation/articles/VaadinCDI.asciidoc
+++ b/documentation/articles/VaadinCDI.asciidoc
@@ -55,7 +55,7 @@ necessary and might in some cases even cause conflicts. +
* *Objects must be injected* and managed by the CDI implementation in
order to use CDI features.
** *Use @Inject on an instance field* to make the CDI implementation
-inject a managed intstance of the corresponding type.
+inject a managed instance of the corresponding type.
** *Annotate your UI class with @CDIUI("")* to let Vaadin CDI know that
it should inject and use instances of that class when the application is
opened in the browser.
diff --git a/documentation/articles/VaadinOnGrailsDatabaseAccess.asciidoc b/documentation/articles/VaadinOnGrailsDatabaseAccess.asciidoc
index fdf6ffab0e..0b3f847773 100644
--- a/documentation/articles/VaadinOnGrailsDatabaseAccess.asciidoc
+++ b/documentation/articles/VaadinOnGrailsDatabaseAccess.asciidoc
@@ -145,7 +145,7 @@ Database connection
+++++++++++++++++++
As we have covered big part of normal work when developing an
-application, created the persistance layer, maybe next questions are
+application, created the persistence layer, maybe next questions are
coming. Where are the data stored? What database is used and how to
change it?
diff --git a/server/src/main/java/com/vaadin/data/Binder.java b/server/src/main/java/com/vaadin/data/Binder.java
index 2d1f685181..7a2ed319c9 100644
--- a/server/src/main/java/com/vaadin/data/Binder.java
+++ b/server/src/main/java/com/vaadin/data/Binder.java
@@ -423,9 +423,11 @@ public class Binder<BEAN> implements Serializable {
TARGET nullRepresentation) {
return withConverter(
fieldValue -> Objects.equals(fieldValue, nullRepresentation)
- ? null : fieldValue,
+ ? null
+ : fieldValue,
modelValue -> Objects.isNull(modelValue)
- ? nullRepresentation : modelValue);
+ ? nullRepresentation
+ : modelValue);
}
/**
@@ -1516,7 +1518,7 @@ public class Binder<BEAN> implements Serializable {
restoreBeanState(bean, oldValues);
} else if (getBean() == null || bean.equals(getBean())) {
/*
- * Changes have been succesfully saved. The set is only cleared
+ * Changes have been successfully saved. The set is only cleared
* if using readBean/writeBean or when the changes are stored in
* the currently set bean.
*
@@ -2158,7 +2160,8 @@ public class Binder<BEAN> implements Serializable {
Converter<FIELDVALUE, FIELDVALUE> nullRepresentationConverter = Converter
.from(fieldValue -> fieldValue,
modelValue -> Objects.isNull(modelValue)
- ? field.getEmptyValue() : modelValue,
+ ? field.getEmptyValue()
+ : modelValue,
exception -> exception.getMessage());
ConverterDelegate<FIELDVALUE> converter = new ConverterDelegate<>(
nullRepresentationConverter);
diff --git a/server/src/main/java/com/vaadin/event/MouseEvents.java b/server/src/main/java/com/vaadin/event/MouseEvents.java
index 34456f2498..b4b25b9683 100644
--- a/server/src/main/java/com/vaadin/event/MouseEvents.java
+++ b/server/src/main/java/com/vaadin/event/MouseEvents.java
@@ -134,7 +134,7 @@ public interface MouseEvents {
/**
* Checks if the Alt key was down when the mouse event took place.
*
- * @return true if Alt was down when the event occured, false otherwise
+ * @return true if Alt was down when the event occurred, false otherwise
*/
public boolean isAltKey() {
return details.isAltKey();
@@ -143,7 +143,7 @@ public interface MouseEvents {
/**
* Checks if the Ctrl key was down when the mouse event took place.
*
- * @return true if Ctrl was pressed when the event occured, false
+ * @return true if Ctrl was pressed when the event occurred, false
* otherwise
*/
public boolean isCtrlKey() {
@@ -153,7 +153,7 @@ public interface MouseEvents {
/**
* Checks if the Meta key was down when the mouse event took place.
*
- * @return true if Meta was pressed when the event occured, false
+ * @return true if Meta was pressed when the event occurred, false
* otherwise
*/
public boolean isMetaKey() {
@@ -163,7 +163,7 @@ public interface MouseEvents {
/**
* Checks if the Shift key was down when the mouse event took place.
*
- * @return true if Shift was pressed when the event occured, false
+ * @return true if Shift was pressed when the event occurred, false
* otherwise
*/
public boolean isShiftKey() {
diff --git a/server/src/main/java/com/vaadin/server/SessionExpiredHandler.java b/server/src/main/java/com/vaadin/server/SessionExpiredHandler.java
index 5d8c2e13b8..cb0b4cdbc3 100644
--- a/server/src/main/java/com/vaadin/server/SessionExpiredHandler.java
+++ b/server/src/main/java/com/vaadin/server/SessionExpiredHandler.java
@@ -27,9 +27,9 @@ import java.io.IOException;
public interface SessionExpiredHandler extends RequestHandler {
/**
- * Called when the a session expiration has occured and a notification needs
- * to be sent to the user. If a response is written, this method should
- * return <code>true</code> to indicate that no more
+ * Called when the a session expiration has occurred and a notification
+ * needs to be sent to the user. If a response is written, this method
+ * should return <code>true</code> to indicate that no more
* {@link SessionExpiredHandler} handlers should be invoked for the request.
*
* @param request
diff --git a/server/src/main/java/com/vaadin/server/VaadinService.java b/server/src/main/java/com/vaadin/server/VaadinService.java
index b65ae5ad9d..d086b68a12 100644
--- a/server/src/main/java/com/vaadin/server/VaadinService.java
+++ b/server/src/main/java/com/vaadin/server/VaadinService.java
@@ -1629,7 +1629,7 @@ public abstract class VaadinService implements Serializable {
ci.getInternalErrorMessage(), null,
ci.getInternalErrorURL()));
} catch (IOException e) {
- // An exception occured while writing the response. Log
+ // An exception occurred while writing the response. Log
// it and continue handling only the original error.
getLogger().log(Level.WARNING,
"Failed to write critical notification response to the client",
@@ -1657,7 +1657,7 @@ public abstract class VaadinService implements Serializable {
* @param reponseString
* The actual response
* @throws IOException
- * If an error occured while writing the response
+ * If an error occurred while writing the response
*/
public void writeStringResponse(VaadinResponse response, String contentType,
String reponseString) throws IOException {
diff --git a/server/src/main/java/com/vaadin/ui/Button.java b/server/src/main/java/com/vaadin/ui/Button.java
index e235097251..c759a3a440 100644
--- a/server/src/main/java/com/vaadin/ui/Button.java
+++ b/server/src/main/java/com/vaadin/ui/Button.java
@@ -241,7 +241,7 @@ public class Button extends AbstractFocusable
/**
* Checks if the Alt key was down when the mouse event took place.
*
- * @return true if Alt was down when the event occured, false otherwise
+ * @return true if Alt was down when the event occurred, false otherwise
* or if unknown
*/
public boolean isAltKey() {
@@ -255,7 +255,7 @@ public class Button extends AbstractFocusable
/**
* Checks if the Ctrl key was down when the mouse event took place.
*
- * @return true if Ctrl was pressed when the event occured, false
+ * @return true if Ctrl was pressed when the event occurred, false
* otherwise or if unknown
*/
public boolean isCtrlKey() {
@@ -269,7 +269,7 @@ public class Button extends AbstractFocusable
/**
* Checks if the Meta key was down when the mouse event took place.
*
- * @return true if Meta was pressed when the event occured, false
+ * @return true if Meta was pressed when the event occurred, false
* otherwise or if unknown
*/
public boolean isMetaKey() {
@@ -283,7 +283,7 @@ public class Button extends AbstractFocusable
/**
* Checks if the Shift key was down when the mouse event took place.
*
- * @return true if Shift was pressed when the event occured, false
+ * @return true if Shift was pressed when the event occurred, false
* otherwise or if unknown
*/
public boolean isShiftKey() {
diff --git a/server/src/main/java/com/vaadin/ui/Upload.java b/server/src/main/java/com/vaadin/ui/Upload.java
index a23e273e09..9096d8bc40 100644
--- a/server/src/main/java/com/vaadin/ui/Upload.java
+++ b/server/src/main/java/com/vaadin/ui/Upload.java
@@ -605,10 +605,10 @@ public class Upload extends AbstractComponent
public interface SucceededListener extends Serializable {
/**
- * Upload successfull..
+ * Upload successful.
*
* @param event
- * the Upload successfull event.
+ * the Upload successful event.
*/
public void uploadSucceeded(SucceededEvent event);
}
diff --git a/server/src/main/java/com/vaadin/util/TimeZoneUtil.java b/server/src/main/java/com/vaadin/util/TimeZoneUtil.java
index ec3d28e730..c3c25b21e4 100644
--- a/server/src/main/java/com/vaadin/util/TimeZoneUtil.java
+++ b/server/src/main/java/com/vaadin/util/TimeZoneUtil.java
@@ -93,11 +93,11 @@ public final class TimeZoneUtil implements Serializable {
if (i.toLocalDate().getYear() != year) {
break;
}
- long epocHours = Duration
+ long epochHours = Duration
.ofSeconds(t.getInstant().getEpochSecond())
.toHours();
long duration = Math.max(t.getDuration().toMinutes(), 0);
- transitionsList.add(epocHours);
+ transitionsList.add(epochHours);
transitionsList.add(duration);
}
}
diff --git a/server/src/test/java/com/vaadin/tests/server/ClassesSerializableTest.java b/server/src/test/java/com/vaadin/tests/server/ClassesSerializableTest.java
index d85c23b5f8..0b6d67f7a7 100644
--- a/server/src/test/java/com/vaadin/tests/server/ClassesSerializableTest.java
+++ b/server/src/test/java/com/vaadin/tests/server/ClassesSerializableTest.java
@@ -130,7 +130,7 @@ public class ClassesSerializableTest {
}
// report fields that use lambda types that won't be serializable
- // (also in syntehtic classes)
+ // (also in synthetic classes)
Stream.of(cls.getDeclaredFields())
.filter(field -> isFunctionalType(field.getGenericType()))
.forEach(nonSerializableFunctionFields::add);
diff --git a/shared/src/main/java/com/vaadin/shared/ui/grid/GridDropTargetRpc.java b/shared/src/main/java/com/vaadin/shared/ui/grid/GridDropTargetRpc.java
index 8309608ca6..f89f2ab626 100644
--- a/shared/src/main/java/com/vaadin/shared/ui/grid/GridDropTargetRpc.java
+++ b/shared/src/main/java/com/vaadin/shared/ui/grid/GridDropTargetRpc.java
@@ -34,21 +34,22 @@ public interface GridDropTargetRpc extends ServerRpc {
* Called when drop event happens on client side.
*
* @param types
- * List of data types from {@code DataTransfer.types} object.
+ * List of data types from {@code DataTransfer.types} object.
* @param data
- * Map containing all types and corresponding data from the {@code
+ * Map containing all types and corresponding data from the
+ * {@code
* DataTransfer} object.
* @param dropEffect
- * the desired drop effect
+ * the desired drop effect
* @param rowKey
- * Key of the row on which the drop event occured.
+ * Key of the row on which the drop event occurred.
* @param dropLocation
- * Location of the drop within the row.
+ * Location of the drop within the row.
* @param mouseEventDetails
- * Mouse event details object containing information about the drop
- * event
+ * Mouse event details object containing information about the
+ * drop event
*/
public void drop(List<String> types, Map<String, String> data,
- String dropEffect, String rowKey,
- DropLocation dropLocation, MouseEventDetails mouseEventDetails);
+ String dropEffect, String rowKey, DropLocation dropLocation,
+ MouseEventDetails mouseEventDetails);
}
diff --git a/uitest/eclipse-run-selected-test.properties b/uitest/eclipse-run-selected-test.properties
index e0f93bfc7c..355fe6b501 100644
--- a/uitest/eclipse-run-selected-test.properties
+++ b/uitest/eclipse-run-selected-test.properties
@@ -56,7 +56,7 @@ com.vaadin.testbench.screenshot.cursor=true
; Uncomment to limit to certain browsers or override in launch configuration
; browsers=winxp-opera10
-; Claim that the server has started succesfully. Needed for TB2 tests to be executed
+; Claim that the server has started successfully. Needed for TB2 tests to be executed
server.start.succeeded=1
; Directory where temporary Java classes are created
diff --git a/uitest/src/main/java/com/vaadin/tests/CustomLayoutDemo.java b/uitest/src/main/java/com/vaadin/tests/CustomLayoutDemo.java
index 2cf1154943..ff0bbf7acb 100644
--- a/uitest/src/main/java/com/vaadin/tests/CustomLayoutDemo.java
+++ b/uitest/src/main/java/com/vaadin/tests/CustomLayoutDemo.java
@@ -153,7 +153,7 @@ public class CustomLayoutDemo extends com.vaadin.server.LegacyApplication
*/
@Override
public void componentEvent(Event event) {
- // Check if event occured at fsTree component
+ // Check if event occurred at fsTree component
if (event.getSource() == menu) {
// Check if event is about changing value
if (event.getClass() == Field.ValueChangeEvent.class) {
diff --git a/uitest/src/main/java/com/vaadin/tests/TestBench.java b/uitest/src/main/java/com/vaadin/tests/TestBench.java
index 56c5dc986a..c29e46e9d3 100644
--- a/uitest/src/main/java/com/vaadin/tests/TestBench.java
+++ b/uitest/src/main/java/com/vaadin/tests/TestBench.java
@@ -175,7 +175,7 @@ public class TestBench extends com.vaadin.server.LegacyApplication
}
}
- // just partly mach lowercase
+ // just partly match lowercase
for (Object next : menu.getItemIds()) {
if (next instanceof Class) {
Class<?> c = (Class<?>) next;
diff --git a/uitest/src/main/java/com/vaadin/tests/TestCaptionWrapper.java b/uitest/src/main/java/com/vaadin/tests/TestCaptionWrapper.java
index 6cde5ad294..9a63d7a823 100644
--- a/uitest/src/main/java/com/vaadin/tests/TestCaptionWrapper.java
+++ b/uitest/src/main/java/com/vaadin/tests/TestCaptionWrapper.java
@@ -55,7 +55,7 @@ public class TestCaptionWrapper extends CustomComponent implements Listener {
final String eventListenerString = "Component.Listener feedback: ";
Label eventListenerFeedback = new Label(
- eventListenerString + " <no events occured>");
+ eventListenerString + " <no events occurred>");
int count = 0;
public TestCaptionWrapper() {
@@ -120,7 +120,8 @@ public class TestCaptionWrapper extends CustomComponent implements Listener {
test(layout, button);
button.addListener(this);
- final AbstractDateField<?, ?> df = new TestDateField("DateField " + count++);
+ final AbstractDateField<?, ?> df = new TestDateField(
+ "DateField " + count++);
test(layout, df);
final CheckBox cb = new CheckBox("Checkbox " + count++);
diff --git a/uitest/src/main/java/com/vaadin/tests/TreeFilesystemContainer.java b/uitest/src/main/java/com/vaadin/tests/TreeFilesystemContainer.java
index 1ce2f389e2..3f281a14c8 100644
--- a/uitest/src/main/java/com/vaadin/tests/TreeFilesystemContainer.java
+++ b/uitest/src/main/java/com/vaadin/tests/TreeFilesystemContainer.java
@@ -104,7 +104,7 @@ public class TreeFilesystemContainer extends com.vaadin.server.LegacyApplication
*/
@Override
public void componentEvent(Event event) {
- // Check if event occured at fsTree component
+ // Check if event occurred at fsTree component
if (event.getSource() == filesystem) {
// Check if event is about changing value
if (event.getClass() == Field.ValueChangeEvent.class) {
diff --git a/uitest/src/main/java/com/vaadin/tests/components/button/ButtonClick.java b/uitest/src/main/java/com/vaadin/tests/components/button/ButtonClick.java
index 667c0e80ce..9e4701f40b 100644
--- a/uitest/src/main/java/com/vaadin/tests/components/button/ButtonClick.java
+++ b/uitest/src/main/java/com/vaadin/tests/components/button/ButtonClick.java
@@ -26,7 +26,7 @@ import com.vaadin.ui.VerticalLayout;
public class ButtonClick extends AbstractReindeerTestUI {
- public static final String SUCCESS_TEXT = "Click received succesfully!";
+ public static final String SUCCESS_TEXT = "Click received successfully!";
public static final String WRONG_BUTTON_TEXT = "Wrong button clicked.";
@Override
diff --git a/uitest/src/main/java/com/vaadin/tests/components/draganddropwrapper/SingleUseDragAndDropUpload.java b/uitest/src/main/java/com/vaadin/tests/components/draganddropwrapper/SingleUseDragAndDropUpload.java
index cd4b180d63..bf315cecff 100644
--- a/uitest/src/main/java/com/vaadin/tests/components/draganddropwrapper/SingleUseDragAndDropUpload.java
+++ b/uitest/src/main/java/com/vaadin/tests/components/draganddropwrapper/SingleUseDragAndDropUpload.java
@@ -59,7 +59,7 @@ public class SingleUseDragAndDropUpload extends AbstractTestUIWithLog {
@Override
public void drop(DragAndDropEvent event) {
Transferable transferable = event.getTransferable();
- log("Drop occured");
+ log("Drop occurred");
if (transferable instanceof WrapperTransferable) {
WrapperTransferable wTransferable = (WrapperTransferable) transferable;
Html5File[] files = wTransferable.getFiles();
diff --git a/uitest/src/main/java/com/vaadin/tests/components/grid/basics/GridBasics.java b/uitest/src/main/java/com/vaadin/tests/components/grid/basics/GridBasics.java
index 21eb8b502a..56d970308d 100644
--- a/uitest/src/main/java/com/vaadin/tests/components/grid/basics/GridBasics.java
+++ b/uitest/src/main/java/com/vaadin/tests/components/grid/basics/GridBasics.java
@@ -256,7 +256,8 @@ public class GridBasics extends AbstractTestUIWithLog {
private void onSingleSelect(SingleSelectionEvent<DataObject> event) {
log("SingleSelectionEvent: Selected: "
+ (event.getSelectedItem().isPresent()
- ? event.getSelectedItem().get().toString() : "none"));
+ ? event.getSelectedItem().get().toString()
+ : "none"));
}
private void onMultiSelect(MultiSelectionEvent<DataObject> event) {
@@ -267,13 +268,14 @@ public class GridBasics extends AbstractTestUIWithLog {
String addedRow = firstAdded.isPresent() ? firstAdded.get().toString()
: "none";
String removedRow = firstRemoved.isPresent()
- ? firstRemoved.get().toString() : "none";
+ ? firstRemoved.get().toString()
+ : "none";
log("SelectionEvent: Added " + addedRow + ", Removed " + removedRow);
}
private Component createMenu() {
MenuBar menu = new MenuBar();
- menu.setErrorHandler(error -> log("Exception occured, "
+ menu.setErrorHandler(error -> log("Exception occurred, "
+ error.getThrowable().getClass().getName() + ": "
+ error.getThrowable().getMessage()));
MenuItem componentMenu = menu.addItem("Component", null);
@@ -361,9 +363,11 @@ public class GridBasics extends AbstractTestUIWithLog {
}
columnsMenu.addItem("Clear sort", item -> grid.clearSortOrder());
- columnsMenu.addItem("Simple resize mode",
- item -> grid.setColumnResizeMode(item.isChecked()
- ? ColumnResizeMode.SIMPLE : ColumnResizeMode.ANIMATED))
+ columnsMenu
+ .addItem("Simple resize mode",
+ item -> grid.setColumnResizeMode(
+ item.isChecked() ? ColumnResizeMode.SIMPLE
+ : ColumnResizeMode.ANIMATED))
.setCheckable(true);
}
@@ -406,13 +410,12 @@ public class GridBasics extends AbstractTestUIWithLog {
? t -> "Row tooltip for row " + t.getRowNumber()
: null))
.setCheckable(true);
- stateMenu
- .addItem("Cell description generator", item -> grid.getColumns()
- .stream().findFirst()
- .ifPresent(c -> c.setDescriptionGenerator(
- item.isChecked() ? t -> "Cell tooltip for row "
+ stateMenu.addItem("Cell description generator",
+ item -> grid.getColumns().stream().findFirst().ifPresent(
+ c -> c.setDescriptionGenerator(item.isChecked()
+ ? t -> "Cell tooltip for row "
+ t.getRowNumber() + ", Column 0"
- : null)))
+ : null)))
.setCheckable(true);
stateMenu.addItem("Item click listener", new Command() {
diff --git a/uitest/src/main/java/com/vaadin/tests/components/orderedlayout/VaadinTunesLayout.java b/uitest/src/main/java/com/vaadin/tests/components/orderedlayout/VaadinTunesLayout.java
index 8ffe3abadd..2599ed55ff 100644
--- a/uitest/src/main/java/com/vaadin/tests/components/orderedlayout/VaadinTunesLayout.java
+++ b/uitest/src/main/java/com/vaadin/tests/components/orderedlayout/VaadinTunesLayout.java
@@ -172,7 +172,7 @@ public class VaadinTunesLayout extends AbstractReindeerTestUI {
rootLayout.addComponent(bottom);
// The splitpanel is by default 100% x 100%, but we'll need to adjust
- // our main window layout to accomodate the height
+ // our main window layout to accommodate the height
rootLayout.setExpandRatio(bottom, 1.0F);
// Give the sidebar less space than the listing
@@ -245,27 +245,26 @@ public class VaadinTunesLayout extends AbstractReindeerTestUI {
new NativeSelect());
// Lets populate the table with random data
- String[] tracks = { "Red Flag", "Millstone", "Not The Sun",
- "Breath", "Here We Are", "Deep Heaven", "Her Voice Resides",
+ String[] tracks = { "Red Flag", "Millstone", "Not The Sun", "Breath",
+ "Here We Are", "Deep Heaven", "Her Voice Resides",
"Natural Tan", "End It All", "Kings", "Daylight Slaving",
"Mad Man", "Resolve", "Teargas", "African Air",
"Passing Bird" };
- String[] times = { "4:12", "6:03", "5:43", "4:32", "3:42",
- "4:45", "2:56", "9:34", "2:10", "3:44", "5:49", "6:30", "5:18",
- "7:42", "3:13", "2:52" };
- String[] artists = { "Billy Talent", "Brand New",
- "Breaking Benjamin", "Becoming The Archetype",
- "Bullet For My Valentine", "Chasing Victory", "Chimaira",
- "Danko Jones", "Deadlock", "Deftones", "From Autumn To Ashes",
- "Haste The Day", "Four Year Strong", "In Flames", "Kemopetrol",
- "John Legend" };
+ String[] times = { "4:12", "6:03", "5:43", "4:32", "3:42", "4:45",
+ "2:56", "9:34", "2:10", "3:44", "5:49", "6:30", "5:18", "7:42",
+ "3:13", "2:52" };
+ String[] artists = { "Billy Talent", "Brand New", "Breaking Benjamin",
+ "Becoming The Archetype", "Bullet For My Valentine",
+ "Chasing Victory", "Chimaira", "Danko Jones", "Deadlock",
+ "Deftones", "From Autumn To Ashes", "Haste The Day",
+ "Four Year Strong", "In Flames", "Kemopetrol", "John Legend" };
String[] albums = { "Once Again", "The Caitiff Choir",
"The Devil And God", "Light Grenades", "Dicthonomy",
"Back In Black", "Dreamer", "Come Clarity", "Year Zero",
"Frames", "Fortress", "Phobia", "The Poison", "Manifesto",
"White Pony", "The Big Dirty" };
- String[] genres = { "Rock", "Metal", "Hardcore", "Indie",
- "Pop", "Alternative", "Blues", "Jazz", "Hip Hop", "Electronica",
+ String[] genres = { "Rock", "Metal", "Hardcore", "Indie", "Pop",
+ "Alternative", "Blues", "Jazz", "Hip Hop", "Electronica",
"Punk", "Hard Rock", "Dance", "R'n'B", "Gospel", "Country" };
for (int i = 0; i < 1000; i++) {
NativeSelect s = new NativeSelect();
diff --git a/uitest/src/main/java/com/vaadin/tests/components/tree/TreeBasicFeatures.java b/uitest/src/main/java/com/vaadin/tests/components/tree/TreeBasicFeatures.java
index 8796e724be..fd1528f8d4 100644
--- a/uitest/src/main/java/com/vaadin/tests/components/tree/TreeBasicFeatures.java
+++ b/uitest/src/main/java/com/vaadin/tests/components/tree/TreeBasicFeatures.java
@@ -67,7 +67,7 @@ public class TreeBasicFeatures extends AbstractTestUIWithLog {
private Component createMenu() {
MenuBar menu = new MenuBar();
- menu.setErrorHandler(error -> log("Exception occured, "
+ menu.setErrorHandler(error -> log("Exception occurred, "
+ error.getThrowable().getClass().getName() + ": "
+ error.getThrowable().getMessage()));
MenuItem componentMenu = menu.addItem("Component", null);
@@ -111,7 +111,8 @@ public class TreeBasicFeatures extends AbstractTestUIWithLog {
componentMenu
.addItem("Style Generator",
menuItem -> tree.setStyleGenerator(menuItem.isChecked()
- ? t -> "level" + t.getDepth() : t -> null))
+ ? t -> "level" + t.getDepth()
+ : t -> null))
.setCheckable(true);
return menu;
diff --git a/uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectAllTest.java b/uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectAllTest.java
index f58e0db6b4..1900ea2447 100644
--- a/uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectAllTest.java
+++ b/uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectAllTest.java
@@ -45,8 +45,8 @@ public class GridSelectAllTest extends GridBasicsTest {
selectionBox.click();
selectionBox.click();
- assertFalse("Exception occured on row reselection.", logContainsText(
- "Exception occured, java.lang.IllegalStateException: No item id for key 101 found."));
+ assertFalse("Exception occurred on row reselection.", logContainsText(
+ "Exception occurred, java.lang.IllegalStateException: No item id for key 101 found."));
}
@Test
diff --git a/uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectionTest.java b/uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectionTest.java
index 93575e26ac..7a11b3375e 100644
--- a/uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectionTest.java
+++ b/uitest/src/test/java/com/vaadin/tests/components/grid/GridSelectionTest.java
@@ -267,7 +267,7 @@ public class GridSelectionTest extends GridBasicsTest {
assertFalse(
"Unexpected NullPointerException when removing selected rows",
logContainsText(
- "Exception occured, java.lang.NullPointerException: null"));
+ "Exception occurred, java.lang.NullPointerException: null"));
}
@Test
diff --git a/uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorBufferedTest.java b/uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorBufferedTest.java
index 288000ff22..9722f0e80e 100644
--- a/uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorBufferedTest.java
+++ b/uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorBufferedTest.java
@@ -177,7 +177,7 @@ public class GridEditorBufferedTest extends GridEditorTest {
private void makeInvalidEdition() {
editRow(5);
assertFalse(logContainsText(
- "Exception occured, java.lang.IllegalStateException"));
+ "Exception occurred, java.lang.IllegalStateException"));
GridEditorElement editor = getGridElement().getEditor();
diff --git a/uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorUnbufferedTest.java b/uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorUnbufferedTest.java
index 9eacb3832e..9a751a70b5 100644
--- a/uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorUnbufferedTest.java
+++ b/uitest/src/test/java/com/vaadin/tests/components/grid/basics/GridEditorUnbufferedTest.java
@@ -32,10 +32,10 @@ import com.vaadin.testbench.elements.GridElement.GridCellElement;
public class GridEditorUnbufferedTest extends GridEditorTest {
- private static final String[] TOGGLE_EDITOR_BUFFERED = {
- "Component", "Editor", "Buffered mode" };
- private static final String[] CANCEL_EDIT = { "Component",
- "Editor", "Cancel edit" };
+ private static final String[] TOGGLE_EDITOR_BUFFERED = { "Component",
+ "Editor", "Buffered mode" };
+ private static final String[] CANCEL_EDIT = { "Component", "Editor",
+ "Cancel edit" };
@Override
@Before
@@ -63,7 +63,7 @@ public class GridEditorUnbufferedTest extends GridEditorTest {
assertEditorOpen();
selectMenuPath(TOGGLE_EDITOR_BUFFERED);
boolean thrown = logContainsText(
- "Exception occured, java.lang.IllegalStateException");
+ "Exception occurred, java.lang.IllegalStateException");
assertTrue("IllegalStateException was not thrown", thrown);
}
diff --git a/uitest/src/test/java/com/vaadin/tests/components/table/MemoryLeakTableTest.java b/uitest/src/test/java/com/vaadin/tests/components/table/MemoryLeakTableTest.java
index 7db4ec1370..9cb5dd0037 100644
--- a/uitest/src/test/java/com/vaadin/tests/components/table/MemoryLeakTableTest.java
+++ b/uitest/src/test/java/com/vaadin/tests/components/table/MemoryLeakTableTest.java
@@ -54,7 +54,7 @@ public class MemoryLeakTableTest extends MultiBrowserTest {
@Test
@Ignore
public void memoryTest() throws IOException {
- // Set breakoint and look memory consuption in Profiler
+ // Set breakpoint and look memory consumption in Profiler
// Mozilla Firefox doesn't provide memory usage profiler, use chrome.
openTestURL();
@@ -75,7 +75,7 @@ public class MemoryLeakTableTest extends MultiBrowserTest {
}
btnDel.click();
}
- // Set breakoint and look memory consuption in Profiler
+ // Set breakpoint and look memory consumption in Profiler
btnAdd = $(ButtonElement.class).get(0);
}
diff --git a/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorBufferedTest.java b/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorBufferedTest.java
index b408308f7b..0e73d68926 100644
--- a/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorBufferedTest.java
+++ b/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorBufferedTest.java
@@ -174,7 +174,7 @@ public class GridEditorBufferedTest extends GridEditorTest {
private void makeInvalidEdition() {
selectMenuPath(EDIT_ITEM_5);
assertFalse(logContainsText(
- "Exception occured, java.lang.IllegalStateException"));
+ "Exception occurred, java.lang.IllegalStateException"));
GridEditorElement editor = getGridElement().getEditor();
@@ -316,7 +316,7 @@ public class GridEditorBufferedTest extends GridEditorTest {
selectMenuPath(EDIT_ITEM_100);
boolean thrown = logContainsText(
- "Exception occured, java.lang.IllegalStateException");
+ "Exception occurred, java.lang.IllegalStateException");
assertTrue("IllegalStateException thrown", thrown);
assertEditorOpen();
diff --git a/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorTest.java b/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorTest.java
index f751e60c2c..7c982dabdb 100644
--- a/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorTest.java
+++ b/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorTest.java
@@ -42,12 +42,12 @@ public abstract class GridEditorTest extends GridBasicFeaturesTest {
.className("v-grid-editor-cancel");
protected static final By BY_EDITOR_SAVE = By
.className("v-grid-editor-save");
- protected static final String[] EDIT_ITEM_5 = { "Component",
- "Editor", "Edit item 5" };
- protected static final String[] EDIT_ITEM_100 = { "Component",
- "Editor", "Edit item 100" };
- protected static final String[] TOGGLE_EDIT_ENABLED = {
- "Component", "Editor", "Enabled" };
+ protected static final String[] EDIT_ITEM_5 = { "Component", "Editor",
+ "Edit item 5" };
+ protected static final String[] EDIT_ITEM_100 = { "Component", "Editor",
+ "Edit item 100" };
+ protected static final String[] TOGGLE_EDIT_ENABLED = { "Component",
+ "Editor", "Enabled" };
@Before
public void setUp() {
@@ -71,7 +71,7 @@ public abstract class GridEditorTest extends GridBasicFeaturesTest {
selectMenuPath(EDIT_ITEM_5);
assertEditorClosed();
boolean thrown = logContainsText(
- "Exception occured, java.lang.IllegalStateException");
+ "Exception occurred, java.lang.IllegalStateException");
assertTrue("IllegalStateException thrown", thrown);
}
@@ -81,7 +81,7 @@ public abstract class GridEditorTest extends GridBasicFeaturesTest {
selectMenuPath(TOGGLE_EDIT_ENABLED);
assertEditorOpen();
boolean thrown = logContainsText(
- "Exception occured, java.lang.IllegalStateException");
+ "Exception occurred, java.lang.IllegalStateException");
assertTrue("IllegalStateException thrown", thrown);
}
diff --git a/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorUnbufferedTest.java b/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorUnbufferedTest.java
index 74cf478291..a4a715d998 100644
--- a/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorUnbufferedTest.java
+++ b/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridEditorUnbufferedTest.java
@@ -31,10 +31,10 @@ import com.vaadin.testbench.elements.GridElement.GridCellElement;
public class GridEditorUnbufferedTest extends GridEditorTest {
- private static final String[] TOGGLE_EDITOR_BUFFERED = {
- "Component", "Editor", "Buffered mode" };
- private static final String[] CANCEL_EDIT = { "Component",
- "Editor", "Cancel edit" };
+ private static final String[] TOGGLE_EDITOR_BUFFERED = { "Component",
+ "Editor", "Buffered mode" };
+ private static final String[] CANCEL_EDIT = { "Component", "Editor",
+ "Cancel edit" };
@Override
@Before
@@ -62,7 +62,7 @@ public class GridEditorUnbufferedTest extends GridEditorTest {
assertEditorOpen();
selectMenuPath(TOGGLE_EDITOR_BUFFERED);
boolean thrown = logContainsText(
- "Exception occured, java.lang.IllegalStateException");
+ "Exception occurred, java.lang.IllegalStateException");
assertTrue("IllegalStateException thrown", thrown);
}
diff --git a/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridStructureTest.java b/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridStructureTest.java
index c23ec16232..53a229a4c0 100644
--- a/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridStructureTest.java
+++ b/uitest/src/test/java/com/vaadin/v7/tests/components/grid/basicfeatures/server/GridStructureTest.java
@@ -512,7 +512,7 @@ public class GridStructureTest extends GridBasicFeaturesTest {
public void testAddThirdRowToGrid() {
openTestURL();
selectMenuPath("Component", "Body rows", "Add third row");
- assertFalse(logContainsText("Exception occured"));
+ assertFalse(logContainsText("Exception occurred"));
}
@Test
diff --git a/client/src/main/java/com/vaadin/client/widgets/ChildFocusAwareFlowPanel.java b/client/src/main/java/com/vaadin/client/widgets/ChildFocusAwareFlowPanel.java
index 0d430f8c7f..d1f7882dff 100644
--- a/client/src/main/java/com/vaadin/client/widgets/ChildFocusAwareFlowPanel.java
+++ b/client/src/main/java/com/vaadin/client/widgets/ChildFocusAwareFlowPanel.java
@@ -35,7 +35,7 @@ import com.vaadin.client.ui.FocusableFlowPanel;
/**
* Focusable flow panel which fires focus/blur events if it or any of its child
- * is focused/blured, but doesn't fire events if it happens between its content
+ * is focused/blurred, but doesn't fire events if it happens between its content
* (child) elements.
*
* @author Vaadin Ltd
@@ -46,33 +46,33 @@ public class ChildFocusAwareFlowPanel extends FocusableFlowPanel
private class FocusBlurHandler implements BlurHandler, FocusHandler {
- private boolean blurOccured;
+ private boolean blurOccurred;
@Override
public void onBlur(BlurEvent event) {
- blurOccured = true;
+ blurOccurred = true;
Scheduler.get().scheduleDeferred(() -> fireBlurEvent(event));
}
@Override
public void onFocus(FocusEvent event) {
- if (!blurOccured) {
- // no blur occured before this focus event
+ if (!blurOccurred) {
+ // no blur occurred before this focus event
eventBus.fireEvent(event);
} else {
// blur occured before this focus event
// another component inside the panel was
- // blurred => do not fire the focus and set blurOccured to
+ // blurred => do not fire the focus and set blurOccurred to
// false, so
// blur will not be fired, too
- blurOccured = false;
+ blurOccurred = false;
}
}
private void fireBlurEvent(BlurEvent event) {
- if (blurOccured) {
+ if (blurOccurred) {
eventBus.fireEvent(event);
- blurOccured = false;
+ blurOccurred = false;
}
}
}
@@ -46,33 +46,33 @@ public class ChildFocusAwareFlowPanel extends FocusableFlowPanel
eventBus.fireEvent(event);
} else {
- // blur occured before this focus event
+ // blur occurred before this focus event
// another component inside the panel was
diff --git a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java
index 4abcc75f4d..dcca730f36 100644
--- a/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java
+++ b/compatibility-client/src/main/java/com/vaadin/v7/client/ui/VOptionGroup.java
@@ -83,9 +83,9 @@ public class VOptionGroup extends VOptionGroupBase
* optiongroup: if a control inside this optiongroup gains focus right after
* blur of another control inside this optiongroup (meaning: if onFocus
* fires after onBlur has fired), the blur and focus won't be sent to the
* server side as only a focus change inside this optiongroup occured
*/
- private boolean blurOccured = false;
+ private boolean blurOccurred = false;
/** For internal use only. May be removed or replaced in the future. */
public boolean htmlContentAllowed = false;
@@ -276,35 +276,36 @@ public class VOptionGroup extends VOptionGroupBase
@Override
public void onFocus(FocusEvent arg0) {
- if (!blurOccured) {
- // no blur occured before this focus event
+ if (!blurOccurred) {
+ // no blur occurred before this focus event
// panel was blurred => fire the event to the server side if
// requested by server side
if (sendFocusEvents) {
client.updateVariable(paintableId, EventId.FOCUS, "", true);
}
} else {
// blur occured before this focus event
// another control inside the panel (checkbox / radio box) was
- // blurred => do not fire the focus and set blurOccured to false, so
+ // blurred => do not fire the focus and set blurOccurred to false,
+ // so
// blur will not be fired, too
- blurOccured = false;
+ blurOccurred = false;
}
}
@Override
public void onBlur(BlurEvent arg0) {
- blurOccured = true;
+ blurOccurred = true;
if (sendBlurEvents) {
Scheduler.get().scheduleDeferred(new Command() {
@Override
public void execute() {
- // check whether blurOccured still is true and then send the
- // event out to the server
- if (blurOccured) {
+ // check whether blurOccurred still is true and then send
+ // the event out to the server
+ if (blurOccurred) {
client.updateVariable(paintableId, EventId.BLUR, "",
true);
- blurOccured = false;
+ blurOccurred = false;
}
}
});
@@ -83,9 +83,9 @@ public class VOptionGroup extends VOptionGroupBase
* blur of another control inside this optiongroup (meaning: if onFocus
* fires after onBlur has fired), the blur and focus won't be sent to the
- * server side as only a focus change inside this optiongroup occured
+ * server side as only a focus change inside this optiongroup occurred
*/
@@ -276,35 +276,36 @@ public class VOptionGroup extends VOptionGroupBase
}
} else {
- // blur occured before this focus event
+ // blur occurred before this focus event
// another control inside the panel (checkbox / radio box) was